hilbert_modular_group: Algorithms for Hilbert modular groups
============================================================

Description
-----------

Algorithms for Hilbert modular groups

License
-------

GPL v3

Upstream Contact
----------------

https://pypi.org/project/hilbert-modular-group/
